@@ -18,7 +18,6 @@ class Stack(aws_cdk.Stack):
         )
         self.error_topic = error_topic if error_topic else self.create_sns_topic(f'{id}ErrorTopic')
         self.lambda_directory = lambda_directory
-        self.vpc = self.get_vpc()
 
     def create_sns_topic(self, display_name):
         return aws_cdk.aws_sns.Topic(
@@ -29,8 +28,8 @@ class Stack(aws_cdk.Stack):
     def create_lambda_function(self, function_name=None):
         raise NotImplementedError
 
-    def get_vpc(self):
-        return aws_cdk.aws_ecs.Vpc.from_lookup(
+    def get_vpc(self, vpc_id=None):
+        return aws_cdk.aws_ec2.Vpc.from_lookup(
             self, 'Vpc',
-            vpc_id=self.node.try_get_context('vpc_id')
+            vpc_id=vpc_id if vpc_id else self.node.try_get_context('vpc_id')
         )
\ No newline at end of file
